==> mx-bootrepair_23.4.tar.xz: mx-bootrepair-23.4/translations/mx-boot-repair_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Boot Repair és una utilitat que es pot usar per a reinstal·lar el carregador GRUB als sistemes ESP (EFI System Partition), MBR (Master Boot Record) o a la partició arrel. Dóna l&apos;opció de reconstruir el fitxer de configuració del GRUB i fer còpia de seguretat o restaurar el MBR o PBR (arrel).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Què voldríeu fer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Còpia de seguretat del MBR o PBR (només arrencada antiga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstal·la el carregador GRUB en ESP, MBR o PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Repara el fitxer de configuració del GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaura el MBR o PBR de la còpia de seguretat (només arrencada antiga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Select Boot Method</source>
        <translation>Trieu el mètode d&apos;arrencada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Registre d&apos;Arrencada Principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Arrel (Registre d&apos;Arrencada de Partició)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>root</source>
        <translation>Arrel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Install on:</source>
        <translation>Instal·la a: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Location:</source>
        <translation>Ubicació: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Select root location:</source>
        <translation>Trieu la ubicació de l&apos;arrel:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Partició de Sistema EFI </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancel·la els canvis i surt </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Aplica els canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>S&apos;està instal·lant GRUB al dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="463"/>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="571"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <location filename="../mainwindow.cpp" line="592"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Could not create a temporary folder</source>
        <translation>No s&apos;ha pogut crear un directori temporal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>No es pot establir l&apos;entorn de chroot.
Si us plau, verifiqueu la ubicació triada. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>S&apos;està reconstruint el fitxer de configuració del GRUB (grub.cfg).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Fent còpia de seguretat del MBR o PBR del dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Warning</source>
        <translation>Atenció </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>You are going to write the content of </source>
        <translation>Ara s&apos;enregistrarà el contingut de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source> to </source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>

Are you sure?</source>
        <translation>

N&apos;esteu segurs? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurant el MBR/PBR de la còpia de seguretat al dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>No trobo la partició EFI de sistema (ESP) a cap disc del sistema. Si us plau, creeu un ESP i torneu a provar-ho.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Select %1 location:</source>
        <translation>Trieu la ubicació de %1 :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>S&apos;ha acabat el procés amb èxit. &lt;p&gt;&lt;b&gt;Voleu sortir de MX Boot Repair?&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>El procés ha acabat. Hi ha hagut errors.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Entreu la contrasenya per desbloquejar la partició encriptada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Ho sento, no puc configurar el contenidor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="538"/>
        <source>Select GRUB location</source>
        <translation>Trieu la ubicació de GRUB </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select Item to Back Up</source>
        <translation>Trieu l&apos;element per fer còpia de seguretat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Select Item to Restore</source>
        <translation>Trieu l&apos;element a restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>No location was selected.</source>
        <translation>No s&apos;ha seleccionat cap ubicació.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Si us plau, seleccioneu la partició arrel que voleu esmenar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>Select backup file name</source>
        <translation>Trieu el nom del fitxer de còpia de seguretat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>No file was selected.</source>
        <translation>No s&apos;ha triat cap fitxer. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Trieu un fitxer de còpia de seguretat de MBR o PBR </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa senzill de reparació d&apos;arrencada per MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="616"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Ho sento, no puc muntar la partició %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
    <message>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="vanished">Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_23.7.tar.xz: mx-bootrepair-23.7/translations/mx-boot-repair_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Boot Repair és una utilitat que es pot usar per a reinstal·lar el carregador GRUB als sistemes ESP (EFI System Partition), MBR (Master Boot Record) o a la partició arrel. Dóna l&apos;opció de reconstruir el fitxer de configuració del GRUB i fer còpia de seguretat o restaurar el MBR o PBR (arrel).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Què voldríeu fer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Còpia de seguretat del MBR o PBR (només arrencada antiga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstal·la el carregador GRUB en ESP, MBR o PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Repara el fitxer de configuració del GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaura el MBR o PBR de la còpia de seguretat (només arrencada antiga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Select Boot Method</source>
        <translation>Trieu el mètode d&apos;arrencada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Registre d&apos;Arrencada Principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Arrel (Registre d&apos;Arrencada de Partició)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>root</source>
        <translation>Arrel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Install on:</source>
        <translation>Instal·la a: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Location:</source>
        <translation>Ubicació: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Select root location:</source>
        <translation>Trieu la ubicació de l&apos;arrel:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Partició de Sistema EFI </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancel·la els canvis i surt </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Aplica els canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>S&apos;està instal·lant GRUB al dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <location filename="../mainwindow.cpp" line="440"/>
        <location filename="../mainwindow.cpp" line="464"/>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="572"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="587"/>
        <location filename="../mainwindow.cpp" line="593"/>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>No es pot establir l&apos;entorn de chroot.
Si us plau, verifiqueu la ubicació triada. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>S&apos;està reconstruint el fitxer de configuració del GRUB (grub.cfg).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Fent còpia de seguretat del MBR o PBR del dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Warning</source>
        <translation>Atenció </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>You are going to write the content of </source>
        <translation>Ara s&apos;enregistrarà el contingut de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source> to </source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>

Are you sure?</source>
        <translation>

N&apos;esteu segurs? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurant el MBR/PBR de la còpia de seguretat al dispositiu %1 .</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>No trobo la partició EFI de sistema (ESP) a cap disc del sistema. Si us plau, creeu una ESP i torneu a provar-ho.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Select %1 location:</source>
        <translation>Trieu la ubicació de %1 :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>S&apos;ha acabat el procés amb èxit. &lt;p&gt;&lt;b&gt;Voleu sortir de MX Boot Repair?&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>El procés ha acabat. Hi ha hagut errors.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Entreu la contrasenya per desbloquejar la partició encriptada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Ho sento, no puc configurar el contenidor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Select GRUB location</source>
        <translation>Trieu la ubicació de GRUB </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Select Item to Back Up</source>
        <translation>Trieu l&apos;element per fer còpia de seguretat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Select Item to Restore</source>
        <translation>Trieu l&apos;element a restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>No location was selected.</source>
        <translation>No s&apos;ha seleccionat cap ubicació.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Si us plau, seleccioneu la partició arrel que voleu esmenar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Select backup file name</source>
        <translation>Trieu el nom del fitxer de còpia de seguretat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>No file was selected.</source>
        <translation>No s&apos;ha triat cap fitxer. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Trieu un fitxer de còpia de seguretat de MBR o PBR </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa senzill de reparació d&apos;arrencada per MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="617"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Ho sento, no puc muntar la partició %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Could not create a temporary folder</source>
        <translation>No he pogut crear un directori temporal</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
</context>
</TS>
